//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
var script$1 = {
  name: "Draggable",
  props: {
    classOnDrag: String,
    payload: {
      type: Object,
      default: {}
    }
  },
  emits: ["startDrag", "endDrag"],

  data() {
    return {
      dragInProgress: false,
      isInvisible: false,
      originalPosition: {}
    };
  },

  computed: {
    elementWidth() {
      return this.$refs.draggable.offsetWidth;
    },

    elementHeight() {
      return this.$refs.draggable.offsetHeight;
    }

  },
  methods: {
    setOriginalPosition() {
      this.originalPosition.left = this.$refs.draggable.offsetLeft;
      this.originalPosition.top = this.$refs.draggable.offsetTop;
    },

    startDrag(event) {
      if (event.dataTransfer) {
        setTimeout(() => {
          this.isInvisible = true;
        }, 0);
        this.dragInProgress = true;
        event.dataTransfer.dropEffect = "move";
        event.dataTransfer.effectAllowed = "move";
        event.dataTransfer.setData("payload", JSON.stringify(this.payload));
      }

      this.$emit("startDrag", this.payload);
    },

    endDrag() {
      this.isInvisible = false;
      this.dragInProgress = false;
      this.$emit("endDrag", this.payload);
    },

    setElementPosition(top, left) {
      this.$refs.draggable.style.top = top;
      this.$refs.draggable.style.left = left;
    },

    touchStart(event) {
      this.dragInProgress = true;
      this.$refs.draggable.style.position = "relative";
      this.startDrag(event);
    },

    touchMove(event) {
      if (!event.targetTouches) return;
      if (event.targetTouches.length !== 1) return;
      const touchLocation = event.targetTouches[0];
      this.setElementPosition(touchLocation.pageY - this.elementHeight / 2 - (this.originalPosition.top || 0) + "px", touchLocation.pageX - this.elementWidth / 2 - (this.originalPosition.left || 0) + "px");
    },

    touchEnd(event) {
      this.dragInProgress = false;
      this.$refs.draggable.style.position = "static";
      if (this.originalPosition.left !== undefined && this.originalPosition.top !== undefined) this.setElementPosition(this.originalPosition.top, this.originalPosition.left);
      if (!event.changedTouches || event.changedTouches.length !== 1) return;
      const payload = this.payload;
      const touchLocation = event.changedTouches[0];
      const x = touchLocation.pageX;
      const y = touchLocation.pageY;
      const detail = {
        position: {
          x,
          y
        },
        payload
      };
      const dropEvent = new CustomEvent("MobileDrop", {
        detail
      });
      document.dispatchEvent(dropEvent);
      this.endDrag();
    }

  },

  mounted() {
    this.setOriginalPosition();
    window.addEventListener("resize", this.setOriginalPosition);
  },

  unmounted() {
    window.removeEventListener("resize");
  }

};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__$1 = script$1;
/* template */

var __vue_render__$1 = function () {
  var _obj;

  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', _vm._b({
    ref: "draggable",
    class: (_obj = {}, _obj[_vm.classOnDrag] = _vm.dragInProgress, _obj),
    staticStyle: {
      "position": "relative"
    },
    style: {
      display: _vm.isInvisible ? 'none' : 'inherit'
    },
    attrs: {
      "draggable": "",
      "drag-in-progress": _vm.dragInProgress
    },
    on: {
      "dragstart": _vm.startDrag,
      "dragend": _vm.endDrag,
      "touchstart": _vm.touchStart,
      "touchend": _vm.touchEnd,
      "touchmove": _vm.touchMove
    }
  }, 'div', _vm.$attrs, false), [_vm._t("default")], 2);
};

var __vue_staticRenderFns__$1 = [];
/* style */

const __vue_inject_styles__$1 = undefined;
/* scoped */

const __vue_scope_id__$1 = undefined;
/* module identifier */

const __vue_module_identifier__$1 = undefined;
/* functional template */

const __vue_is_functional_template__$1 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$2 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$1,
  staticRenderFns: __vue_staticRenderFns__$1
}, __vue_inject_styles__$1, __vue_script__$1, __vue_scope_id__$1, __vue_is_functional_template__$1, __vue_module_identifier__$1, false, undefined, undefined, undefined);

var __vue_component__$3 = __vue_component__$2;

//
//
//
//
//
//
//
//
//
//
//
//
//
var script = {
  name: "Dropable",
  emits: ["onDrop"],

  data() {
    return {
      eventListener: null
    };
  },

  computed: {
    left() {
      return this.$refs.dropable.offsetLeft;
    },

    right() {
      return this.$refs.dropable.offsetLeft + this.$refs.dropable.offsetWidth;
    },

    top() {
      return this.$refs.dropable.offsetTop;
    },

    bottom() {
      return this.$refs.dropable.offsetTop + this.$refs.dropable.offsetHeight;
    }

  },
  methods: {
    dropHandler(event) {
      event.preventDefault();
      const payload = JSON.parse(event.dataTransfer.getData("payload"));
      this.$emit("onDrop", payload);
    },

    areCoordinatesInElement(x, y) {
      const horizontal = x > this.left && x < this.right;
      const vertical = y > this.top && y < this.bottom;
      return horizontal && vertical;
    },

    registerEventListener() {
      const vm = this;
      this.eventListener = document.addEventListener("MobileDrop", dropEvent => {
        if (!dropEvent.detail || !dropEvent.detail.position) return;
        const {
          x,
          y
        } = dropEvent.detail.position;
        if (!vm.areCoordinatesInElement(x, y)) return;
        vm.$emit("onDrop", dropEvent.detail.payload);
      });
    }

  },

  mounted() {
    this.registerEventListener();
  },

  unmounted() {
    if (this.eventListener) document.removeEventListener(this.eventListener);
  }

};

/* script */
const __vue_script__ = script;
/* template */

var __vue_render__ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', _vm._b({
    ref: "dropable",
    attrs: {
      "id": "drop-handler"
    },
    on: {
      "drop": _vm.dropHandler,
      "dragenter": function ($event) {
        $event.preventDefault();
      },
      "dragover": function ($event) {
        $event.preventDefault();
      }
    }
  }, 'div', _vm.$attrs, false), [_vm._t("default")], 2);
};

var __vue_staticRenderFns__ = [];
/* style */

const __vue_inject_styles__ = undefined;
/* scoped */

const __vue_scope_id__ = undefined;
/* module identifier */

const __vue_module_identifier__ = undefined;
/* functional template */

const __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

var __vue_component__$1 = __vue_component__;

/* eslint-disable import/prefer-default-export */

var components = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Draggable: __vue_component__$3,
  Dropable: __vue_component__$1
});

// Import vue components

const install = function installVueCrossPlatformDragDrop(Vue) {
  Object.entries(components).forEach(_ref => {
    let [componentName, component] = _ref;
    Vue.component(componentName, component);
  });
}; // Create module definition for Vue.use()

export { __vue_component__$3 as Draggable, __vue_component__$1 as Dropable, install as default };
